@@ -1,8 +1,10 @@
-int fatal(const char * msg);
-void * xmalloc(size_t nbytes);
-float * fMalloc(size_t numElts);
-double * dMalloc(size_t numElts);
-size_t * stMalloc(size_t n);
+void fatal(const char * msg);
+void getComputeNumber(int * major, int * minor);
+void checkDoubleCapable(const char * failMsg);
+// void * xmalloc(size_t nbytes);
+// float * fMalloc(size_t numElts);
+// double * dMalloc(size_t numElts);
+// size_t * stMalloc(size_t n);
 char * getTime();
 void getRandVect(float * vect, size_t n);
 void printVect(int n, const float * vect, const char * msg);
